@@ -1,10 +1,6 @@
 #!/usr/local/bin/perl
 
-# $Id$
-# $LastChangedDate$
-# $Rev$
-
-use lib qw(./lib ../lib);
+use lib qw( /home/tobeya/work/CPAN/Nagios-Objects/lib );
 use Nagios::StatusLog;
 use Benchmark ':hireswallclock';
 use Getopt::Std;
@@ -12,21 +8,19 @@ use Data::Dumper;
 
 =head1 NAME
 
-statusdat_demo.pl - test the StatusLog module
-
 =head1 USAGE
 
 perl statusdat_demo.pl -l /var/opt/nagios/status.dat
 
 =head1 NOTES
 
-Please send the benchmark outputs to duncs@cpan.org so I can see how the 
-performance is on boxes and configs other than my own.
+Please send the benchmark outputs to tobeya@cpan.org so I can see how the performance
+is on boxes and configs other than my own.
 
 =cut
 
 our $opt_l;
-getopt('l:');
+getopt( 'l:' );
 die "Must specify location of Nagios status log with -l option."
     if ( !$opt_l );
 
@@ -38,8 +32,9 @@ my $bench_postparse = Benchmark->new;
 #print Dumper( $log );
 
 foreach my $host ( $log->list_hosts ) {
-    my $obj = $log->host($host);
-    printf "Host: %s Last Update: %d\n", $obj->host_name, $obj->last_update;
+    my $obj = $log->host( $host );
+    printf "Host: %s Last Update: %d\n",
+                $obj->host_name, $obj->last_update;
 
 }
 
@@ -49,6 +44,6 @@ printf "Started at %d", $prog->program_start;
 my $bench_postprint = Benchmark->new;
 
 printf "\nTime to parse: %s\nTime to print: %s\n\n",
-    timestr( timediff( $bench_postparse, $bench_begin ) ),
-    timestr( timediff( $bench_postprint, $bench_postparse ) );
+        timestr(timediff( $bench_postparse, $bench_begin )), 
+        timestr(timediff( $bench_postprint, $bench_postparse ));
 
